r"""

The OpenRPA package (from UnicodeLabs)

"""
__version__ = 'v1.0.13'
__all__ = [
    'GUI','Clipboard','IntegrationOrchestrator','Window', 'ProcessCommunicator'
]
__author__ = 'Ivan Maslov <ivan.maslov@unicodelabs.ru>'
from . import GUI
from . import Clipboard
from . import IntegrationOrchestrator
from . import Window
from . import ProcessCommunicator